@@ -99,7 +99,6 @@ class hdimage(object):
         self.empty = True
         try:
             self.ctx = csp.Crypt(self.cont, csp.PROV_GOST_2001_DH, csp.CRYPT_SILENT)
-            self.empty = False
         except ValueError:
             try:
                 self.ctx = csp.Crypt(
@@ -108,17 +107,22 @@ class hdimage(object):
                 self.broken = True
                 self.ctx = None
         else:
-            key = self.ctx.get_key()
             try:
-                cert = key.extract_cert(csp.AT_KEYEXCHANGE)
-                self.certs['AT_KEYEXCHANGE'] = _cert_info(cert)
-            except:
-                pass
-            try:
-                cert = key.extract_cert(csp.AT_SIGNATURE)
-                self.certs['AT_SIGNATURE'] = _cert_info(cert)
-            except:
-                pass
+                key = self.ctx.get_key()
+            except ValueError:
+                self.empty = True
+            else:
+                self.empty = False
+                try:
+                    cert = key.extract_cert(csp.AT_KEYEXCHANGE)
+                    self.certs['AT_KEYEXCHANGE'] = _cert_info(cert)
+                except:
+                    pass
+                try:
+                    cert = key.extract_cert(csp.AT_SIGNATURE)
+                    self.certs['AT_SIGNATURE'] = _cert_info(cert)
+                except:
+                    pass
 
         if not self.broken:
             self.shortcut = self.ctx.uniq_name()
@@ -204,7 +208,7 @@ class hdimage(object):
                         if fn.startswith(dirname) and fn.endswith('.key'))
         _ensure(filenames >= cls._names, 'Incomplete file set in archive')
         certs = list(x for x in names
-                     if x.endswith('.cer') and not os.path.split(x)[0])
+                     if x.endswith('.cer'))
         standard_certs = set(x[:-4] for x in certs
                              if x[:-4] in cls._keyspecs)
         non_standard_certs = set(x for x in certs
